@@ -22,11 +22,19 @@ def main(request):
 def get(lst,index,default):
     if index<len(lst): return lst[index]
     return default
-def findChanges(old_state,new_state):
+def findChanges(old_state,new_state,key_name=None):
     res="<ul>"
     if type(old_state)==type({}):
         for key in old_state:
-            if old_state[key]!=new_state.get(key,None):
+            if key == "_type":
+                if old_state[key]=="datetime":
+                    if datetime.datetime.strptime(old_state["value"],"%Y-%m-%d %H:%M:%S").strftime("%Y-%m-%dT%H:%M:%SZ") != new_state:
+                        res += "<li>%s:: %s ----> %s</li>" % (key_name, old_state.get("value"), new_state)
+                elif old_state[key]=="date":
+                    if datetime.datetime.strptime(old_state["value"],"%Y-%m-%d").strftime("%Y-%m-%d") != new_state:
+                        res += "<li>%s:: %s ----> %s</li>" % (key_name, old_state.get("value"), new_state)
+
+            elif old_state[key]!=new_state.get(key,None):
                 if type(old_state[key]) in [type({}),type([])]:
                     try:
                         res+= "<li>"+findChanges(old_state.get(key,{}),new_state.get(key,{}))+"</li>"
